summaryrefslogtreecommitdiffstats
path: root/Lib/asyncore.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/asyncore.py')
-rw-r--r--Lib/asyncore.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/Lib/asyncore.py b/Lib/asyncore.py
index aaa9e7c..f790c8a 100644
--- a/Lib/asyncore.py
+++ b/Lib/asyncore.py
@@ -54,9 +54,10 @@ import warnings
import os
from errno import EALREADY, EINPROGRESS, EWOULDBLOCK, ECONNRESET, EINVAL, \
- ENOTCONN, ESHUTDOWN, EINTR, EISCONN, EBADF, ECONNABORTED, errorcode
+ ENOTCONN, ESHUTDOWN, EINTR, EISCONN, EBADF, ECONNABORTED, EPIPE, errorcode
-_DISCONNECTED = frozenset((ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED))
+_DISCONNECTED = frozenset((ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED, EPIPE,
+ EBADF))
try:
socket_map
@@ -111,7 +112,7 @@ def readwrite(obj, flags):
if flags & (select.POLLHUP | select.POLLERR | select.POLLNVAL):
obj.handle_close()
except socket.error as e:
- if e.args[0] not in (EBADF, ECONNRESET, ENOTCONN, ESHUTDOWN, ECONNABORTED):
+ if e.args[0] not in _DISCONNECTED:
obj.handle_error()
else:
obj.handle_close()
@@ -355,7 +356,7 @@ class dispatcher:
except TypeError:
return None
except socket.error as why:
- if why.args[0] in (EWOULDBLOCK, ECONNABORTED):
+ if why.args[0] in (EWOULDBLOCK, ECONNABORTED, EAGAIN):
return None
else:
raise